@@ -1,5 +1,6 @@
 require 'rexml/document'
 require 'iplayer/errors'
+require 'iplayer/constants'
 
 module IPlayer
 class Metadata
@@ -21,7 +22,17 @@ class Metadata
   end
 
   def filetype
-    radio? ? 'mp3' : 'mov'
+    radio? ? AUDIO_FILETYPE : VIDEO_FILETYPE
+  end
+
+  def versions
+    versions = {}
+    REXML::XPath.each(metadata, '//playlist/item') do |node|
+      version_pid = node.attributes['identifier'] or next
+      alternate_id = REXML::XPath.first(node, 'alternate').attributes['id'] rescue 'anonymous'
+      versions[alternate_id] = version_pid
+    end
+    versions
   end
 
 private
